using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace FileFinder
{
    public partial class Form1 : Form
    {
        private string rootDir;

        public Form1()
        {
            InitializeComponent();
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
            rootDir = Environment.GetFolderPath(Environment.SpecialFolder.MyDocuments);
            linkLabelRootDir.Text = string.Format("{0}.  (Click to Change)", rootDir);
            dateTimePickerEpoch.Value = DateTime.Now - TimeSpan.FromDays(1);
        }

        private void linkLabelRootDir_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            folderBrowserDialogRootPath.SelectedPath = rootDir;
            if (DialogResult.OK == folderBrowserDialogRootPath.ShowDialog())
            {
                rootDir = folderBrowserDialogRootPath.SelectedPath;
                linkLabelRootDir.Text = string.Format("{0}.  (Click to Change)", rootDir);
            }
        }

        private FindFilesWorker worker;

        private void buttonGo_Click(object sender, EventArgs e)
        {
            if (worker == null)
            {
                fileInfoBindingSource.Clear();
                TimeSpan since = DateTime.Now - dateTimePickerEpoch.Value;
                worker = new FindFilesWorker(rootDir, since);
                worker.OnEndWork += new EventHandler<FindFilesCompletedEventArgs>(worker_OnEndWork);
                worker.OnWorkProgress += new EventHandler<FindFilesProgressEventArgs>(worker_OnWorkProgress);
                buttonGo.Text = "Cancel!";
                worker.StartWork();
            }
            else
            {
                worker.RequestCancel();
            }
        }

        void worker_OnWorkProgress(object sender, FindFilesProgressEventArgs e)
        {
            fileInfoBindingSource.Add(e.CurrentFile);
        }

        void worker_OnEndWork(object sender, FindFilesCompletedEventArgs e)
        {
            FindFilesWorker source = sender as FindFilesWorker;
            this.buttonGo.Text = "Go!";
            source.OnEndWork -= new EventHandler<FindFilesCompletedEventArgs>(worker_OnEndWork);
            source.OnWorkProgress -= new EventHandler<FindFilesProgressEventArgs>(worker_OnWorkProgress);
        }

    }
}